ahbicht.content\_evaluation.evaluators module
=============================================

.. automodule:: ahbicht.content_evaluation.evaluators
   :members:
   :undoc-members:
   :show-inheritance:
